Documentation
¶
Overview ¶
Package otel supports OpenTelemetry tracing and metrics for the Go Cloud Development Kit.
Index ¶
- func BytesMeasure(pkg string, provider string, meterName string, description string) metric.Int64Counter
- func CounterView(pkg string, meterName string, description string) []sdkmetric.View
- func DimensionlessMeasure(pkg string, provider string, meterName string, description string) metric.Int64Counter
- func LatencyMeasure(pkg string, provider string) metric.Float64Histogram
- func ProviderName(driver any) string
- func Views(pkg string) []sdkmetric.View
- type Tracer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BytesMeasure ¶ added in v0.43.0
func BytesMeasure(pkg string, provider string, meterName string, description string) metric.Int64Counter
BytesMeasure creates a counter for bytes measurements.
func CounterView ¶ added in v0.43.0
CounterView returns summation views that add up individual measurements the counter takes.
func DimensionlessMeasure ¶ added in v0.43.0
func DimensionlessMeasure(pkg string, provider string, meterName string, description string) metric.Int64Counter
DimensionlessMeasure creates a simple counter specifically for dimensionless measurements.
func LatencyMeasure ¶ added in v0.43.0
func LatencyMeasure(pkg string, provider string) metric.Float64Histogram
LatencyMeasure returns the measure for method call latency used by Go CDK APIs.
func ProviderName ¶
ProviderName returns the name of the provider associated with the driver value. It is intended to be used as the provider argument to NewTracer. It actually returns the package path of the driver's type.
Types ¶
Click to show internal directories.
Click to hide internal directories.